package com.qianhe.mapper;

import com.qianhe.domain.JygxYyxtwh;

import java.util.List;


/**
 * 经验共享-应用系统维护Mapper接口
 *
 * @author qianhe
 * @date 2024-07-29
 */
public interface JygxYyxtwhMapper
{
    /**
     * 查询经验共享-应用系统维护
     *
     * @param yyxtid 经验共享-应用系统维护主键
     * @return 经验共享-应用系统维护
     */
    public JygxYyxtwh selectJygxYyxtwhByYyxtid(Long yyxtid);

    /**
     * 查询经验共享-应用系统维护列表
     *
     * @param jygxYyxtwh 经验共享-应用系统维护
     * @return 经验共享-应用系统维护集合
     */
    public List<JygxYyxtwh> selectJygxYyxtwhList(JygxYyxtwh jygxYyxtwh);

    /**
     * 新增经验共享-应用系统维护
     *
     * @param jygxYyxtwh 经验共享-应用系统维护
     * @return 结果
     */
    public int insertJygxYyxtwh(JygxYyxtwh jygxYyxtwh);

    /**
     * 修改经验共享-应用系统维护
     *
     * @param jygxYyxtwh 经验共享-应用系统维护
     * @return 结果
     */
    public int updateJygxYyxtwh(JygxYyxtwh jygxYyxtwh);

    /**
     * 删除经验共享-应用系统维护
     *
     * @param yyxtid 经验共享-应用系统维护主键
     * @return 结果
     */
    public int deleteJygxYyxtwhByYyxtid(Long yyxtid);

    /**
     * 批量删除经验共享-应用系统维护
     *
     * @param yyxtids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteJygxYyxtwhByYyxtids(Long[] yyxtids);
}
